Learn R Programming

stochvol (version 1.1.3)

exrates: Euro exchange rate data

Description

The data set contains the daily bilateral prices of one Euro in 23 currencies from January 3, 2000, until April 4, 2012. Conversions to New Turkish Lira and Fourth Romanian Leu have been incorporated.

Usage

data(exrates)

Arguments

source

ECB Statistical Data Warehouse (http://sdw.ecb.europa.eu)

See Also

svsample

Examples

Run this code
data(exrates)
dat <- logret(exrates$USD, demean=TRUE)  ## de-meaned log-returns
res <- svsample(dat)                ## run MCMC sampler
plot(res, forecast=100)             ## display results

Run the code above in your browser using DataLab