Extractors: Common Extractors for 'svdraws' Objects
Description
Some simple extractors returning the corresponding element of an svdraws object.Usage
para(x)
latent(x)
latent0(x)
priors(x)
thinning(x)
runtime(x)
Value
- The return value depends on the actual funtion:
- para(x)extracts the parameter draws and returns them as an
mcmc object. - latent(x)extracts the latent contemporaneous log-volatility draws and returns them as an
mcmc object. - latent0(x)extracts the latent initial log-volatility draws and returns as an
mcmc object. - priors(x)extracts the prior parameters used and returns them in a
list. - thinning(x)extracts the thinning parameters used and returns them in a
list. - runtime(x)extracts the runtime and returns it as a
proc_time object.