mu, phi, sigma (and potentially nu), computed by the density function.paradensplot(x, showobs = TRUE, showprior = TRUE, showxlab = TRUE,
mar = c(1.9, 1.9, 1.9, 0.5), mgp = c(2, 0.6, 0),
simobj = NULL, ...)svdraws object.TRUE) can render the plotting to be quite slow, and you might want to try setting showobs to TRUE.density. The default value is TRUE.par for details. The default value is c(1.9, 1.9, 1.9, 0.5), which is slightly smaller than the R-defaults.par for details. The default value is c(2, 0.6, 0), which is slightly smaller than the R-defaults.svsim as returned by the SV simulation function svsim. If provided, ``true'' data generating values will be added to the plots.plot function.x invisibly.paradensplot is modeled after densplot in the coda package, with some modifications for parameters that have (half-)bounded support.paratraceplot, volplot, plot.svdraws